@@ -944,61 +944,6 @@ PR_GetLibraryFilePathname(const char* name, PRFuncPtr addr) {
   }
   PR_Free(info);
   return result;
-#elif defined(HPUX) && defined(USE_HPSHL)
-  int index;
-  struct shl_descriptor desc;
-  char* result;
-
-  for (index = 0; shl_get_r(index, &desc) == 0; index++) {
-    if (strstr(desc.filename, name) != NULL) {
-      result = PR_Malloc(strlen(desc.filename) + 1);
-      if (result != NULL) {
-        strcpy(result, desc.filename);
-      }
-      return result;
-    }
-  }
-  /*
-   * Since the index value of a library is decremented if
-   * a library preceding it in the shared library search
-   * list was unloaded, it is possible that we missed some
-   * libraries as we went up the list.  So we should go
-   * down the list to be sure that we not miss anything.
-   */
-  for (index--; index >= 0; index--) {
-    if ((shl_get_r(index, &desc) == 0) &&
-        (strstr(desc.filename, name) != NULL)) {
-      result = PR_Malloc(strlen(desc.filename) + 1);
-      if (result != NULL) {
-        strcpy(result, desc.filename);
-      }
-      return result;
-    }
-  }
-  PR_SetError(PR_LIBRARY_NOT_LOADED_ERROR, 0);
-  return NULL;
-#elif defined(HPUX) && defined(USE_DLFCN)
-  struct load_module_desc desc;
-  char* result;
-  const char* module_name;
-
-  if (dlmodinfo((unsigned long)addr, &desc, sizeof desc, NULL, 0, 0) == 0) {
-    PR_SetError(PR_LIBRARY_NOT_LOADED_ERROR, _MD_ERRNO());
-    DLLErrorInternal(_MD_ERRNO());
-    return NULL;
-  }
-  module_name = dlgetname(&desc, sizeof desc, NULL, 0, 0);
-  if (module_name == NULL) {
-    /* should not happen */
-    _PR_MD_MAP_DEFAULT_ERROR(_MD_ERRNO());
-    DLLErrorInternal(_MD_ERRNO());
-    return NULL;
-  }
-  result = PR_Malloc(strlen(module_name) + 1);
-  if (result != NULL) {
-    strcpy(result, module_name);
-  }
-  return result;
 #elif defined(WIN32)
   PRUnichar wname[MAX_PATH];
   HMODULE handle = NULL;
