@@ -8,27 +8,23 @@
 #include <setjmp.h>
 
 /* Fake this out */
-int socketpair (int foo, int foo2, int foo3, int sv[2])
-{
-    printf("error in socketpair\n");
-    exit (-1);
+int socketpair(int foo, int foo2, int foo3, int sv[2]) {
+  printf("error in socketpair\n");
+  exit(-1);
 }
 
-void _MD_EarlyInit(void)
-{
-}
+void _MD_EarlyInit(void) {}
 
-PRWord *_MD_HomeGCRegisters(PRThread *t, int isCurrent, int *np)
-{
+PRWord* _MD_HomeGCRegisters(PRThread* t, int isCurrent, int* np) {
 #ifndef _PR_PTHREADS
-    if (isCurrent) {
-        (void) setjmp(CONTEXT(t));
-    }
+  if (isCurrent) {
+    (void)setjmp(CONTEXT(t));
+  }
 
-    *np = sizeof(CONTEXT(t)) / sizeof(PRWord);
-    return (PRWord *) CONTEXT(t);
+  *np = sizeof(CONTEXT(t)) / sizeof(PRWord);
+  return (PRWord*)CONTEXT(t);
 #else
-    *np = 0;
-    return NULL;
+  *np = 0;
+  return NULL;
 #endif
 }
